<?php
/**
 * @file
 * Contains Attribute and Role Mapping for miniOrange SAML Login Module.
 */

 /**
 * Showing Settings form.
 */
namespace Drupal\miniorange_saml\Form;

use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml\Utilities;
use Drupal\miniorange_saml\MiniorangeSAMLConstants;

class Mapping extends FormBase {
	 
  public function getFormId() {
    return 'miniorange_saml_mapping';
  }
	 
 public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {

  global $base_url;

     Utilities::visual_tour_start($form, $form_state);

     $form['markup_top'] = array(
         '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">
                       <h2>Attribute Mapping (Optional) 
                       <a id="Restart_moTour" class="btn btn-primary btn-sm mo_tour_button_float" onclick="Restart_moTour()">Take a Tour</a></h2><hr><br>'
     );

     $form['miniorange_saml_account_username_by'] = array(
         '#type' => 'select',
         '#title' => t('Login/Create Drupal account by <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">[Standard, Premium and Enterprise]</a>'),
            '#options' => array(
                1 => t('Drupal Email Address'),
            ),
         '#disabled' => TRUE,
         '#attributes' => array('style' => 'width:700px; background-image: inherit; background-color: hsla(0,0%,0%,0.08) !important;-webkit-appearance: menulist;'),
         '#prefix' => '<div id = "mo_saml_username_div_start">',
         '#suffix' => '<br></div><div id="configure_attribute_mapping_start">'
     );

     $form['Configure_Attribute_Mapping_End'] = array(
         '#markup' => '</div><div class="mo_saml_highlight_background_note_1"><b>Note: <code>Username Attribute</code> </b> and <b><code>Email Attribute</code></b> are configurable in 
                 <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Standard, Premium and Enterprise</a> versions of the module.</div>',
     );

      $form['miniorange_saml_username_attribute'] = array(
        '#type' => 'textfield',
        '#title' => t('Username Attribute'),
        '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_username_attribute'),
        '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Username attribute'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_email_attribute'] = array(
          '#type' => 'textfield',
          '#title' => t('Email Attribute'),
          '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_email_attribute'),
          '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Email attribute'),
          '#disabled' => TRUE,
      );

     $form['miniorange_saml_gateway_config1_submit'] = array(
         '#type' => 'submit',
         '#value' => t('Save Configuration'),
         '#prefix' => '<br>',
         '#suffix' => '<br><br>',
     );

     $form['miniorange_saml_enable_rolemapping'] = array(
         '#type' => 'checkbox',
         '#title' => t('Check this option if you want to <b>enable Role Mapping</b>'),
         '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_enable_rolemapping'),
         '#attributes' => array('class="mo_saml_checkbox"'),
         '#description' => t('<b style="color: red">Note:</b> Enable this checkbox first before using any of the feature below.'),
         '#prefix' => '<br><br><div id="Enable_Rolemapping"><h2>Role Mapping</h2><hr><br>',
         '#suffix' => '</div>',
     );

     $mrole = user_role_names(TRUE);
     $default_role_index = \Drupal::configFactory()->getEditable('miniorange_saml.settings')->get('miniorange_saml_default_role_index');

     $form['miniorange_saml_default_mapping'] = array(
         '#type' => 'select',
         '#title' => t('Select default group for the users'),
         '#options' => array_values($mrole),
         '#default_value' => $default_role_index,
         '#attributes' => array('style' => 'width:700px;background-image: inherit;background-color: white;-webkit-appearance: menulist;'),
         '#prefix' => '<div id="Default_Mapping">',
         '#suffix' => '</div>',
     );

     $form['miniorange_saml_disable_role_update'] = array(
         '#type' => 'checkbox',
         '#title' => t('Check this option if you do not want to update user role if roles not mapped '),
         '#disabled' => TRUE,
         '#description'=>t('<b>Note:</b> This feature is availabe in <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Premium and Enterprise</a> versions of the module.'),
         '#prefix' => '<div class="mo_saml_highlight_background_note_1">',
     );

     $form['miniorange_saml_disable_autocreate_users'] = array(
         '#type' => 'checkbox',
         '#title' => t('Check this option if you want to disable <b>auto creation</b> of users if user does not exist.'),
         '#disabled' => TRUE,
         '#description'=>t('<b>Note:</b> This feature is availabe in <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Premium and Enterprise</a> versions of the module.'),
         '#suffix' => '</div>',
     );

     $form['miniorange_saml_gateway_config2_submit'] = array(
         '#type' => 'submit',
         '#value' => t('Save Configuration'),
         '#prefix' => '<br>',
         '#suffix' => '<br><br>',
     );

    $form['markup_cam_attr'] = array(
        '#markup' => '<br><br><h2>Custom Attribute Mapping </h2><hr><br><div class="mo_saml_highlight_background_note_1"><b>Note: </b>Custom Attribute Mapping is configurable in
            <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Standard, Premium and Enterprise</a> versions of the module.</div>',
    );

      $form['markup_cam'] = array(
         '#markup' => '<br><div class="mo_saml_highlight_background_note_1"><p><b>NOTE: </b> Add the Drupal field attributes in the Attribute Name textfield and add the IdP attibutes that you need to map with the drupal attributes in the IdP Attribute Name textfield. 
                                   <br> <b>Attribute Name:</b> It is the user attribute (machine name) whose value you want to set in site.
                                   <br> <b>IdP Attribute Name:</b> It is the name which you want to get from your IDP. It should be unique.</p></div><p><b>For example: If the attribute name in the drupal is name then its machine name will be field_name.</b></p>',
      );

       $form['miniorange_saml_attr5_name'] = array(
           '#type' => 'textfield',
           '#title' => t('Attribute Name 1 '),
           '#attributes' => array('style' => 'width:700px;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Attribute Name'),
           '#disabled' => TRUE,
           '#prefix' => '<div id="Custom_Attribute_Mapping">'
      );

      $form['miniorange_saml_idp_attr5_name'] = array(
        '#type' => 'textfield',
        '#title' => t('IdP Attribute Name 1'),
        '#attributes' => array('style' => 'width:700px;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter IdP Attribute Name'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_attr2_name'] = array(
        '#type' => 'textfield',
        '#title' => t('Attribute Name 2'),
        '#attributes' => array('style' => 'width:700px;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Attribute Name'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_idp_attr2_name'] = array(
        '#type' => 'textfield',
        '#title' => t('IdP Attribute Name 2'),
        '#attributes' => array('style' => 'width:700px;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter IdP Attribute Name'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_attr3_name'] = array(
        '#type' => 'textfield',
        '#title' => t('Attribute Name 3'),
        '#attributes' => array('style' => 'width:700px;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Attribute Name'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_idp_attr3_name'] = array(
        '#type' => 'textfield',
        '#title' => t('IdP Attribute Name 3'),
        '#attributes' => array('style' => 'width:700px;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter IdP Attribute Name'),
        '#disabled' => TRUE,
      );
  
      $form['miniorange_saml_attr4_name'] = array(
        '#type' => 'textfield',
        '#title' => t('Attribute Name 4'),
        '#attributes' => array('style' => 'width:700px;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Attribute Name'),
        '#disabled' => TRUE,
      );

      $form['miniorange_saml_idp_attr4_name'] = array(
        '#type' => 'textfield',
        '#title' => t('IdP Attribute Name 4'),
        '#attributes' => array('style' => 'width:700px;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter IdP Attribute Name'),
        '#disabled' => TRUE,
        '#suffix' => '</div>',
      );

     $form['miniorange_saml_gateway_config3_submit'] = array(
         '#type' => 'submit',
         '#value' => t('Save Configuration'),
         '#disabled' => TRUE,
         '#prefix' => '<br>',
         '#suffix' => '<br><br>',
     );

      $form['markup_custom_role_mapping'] = array(
         '#markup' => '<br/><h2>Custom Role Mapping </h2><hr><br><div class="mo_saml_highlight_background_note_1">
                       <b>Note: </b>Custom Role Mapping is configurable in <a href="' . $base_url . MiniorangeSAMLConstants::LICENSING_TAB_URL .'">Premium and Enterprise</a> versions of the module.</div>',
      );

     $form['miniorange_saml_idp_attr1_name'] = array(
         '#type' => 'textfield',
         '#title' => t('Role Key'),
         '#attributes' => array('style' => 'width:700px; background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Role Attribute'),
         '#description' => '<b>Note:</b> You will find role key value in the test configuration window.<br><br>',
         '#disabled' => TRUE,
     );

      foreach($mrole as $roles) {
        $rolelabel = str_replace(' ','',$roles);
        $form['miniorange_saml_role_' . $rolelabel] = array(
            '#type' => 'textfield',
            '#title' => t($roles),
            '#maxlength' => 255,
            '#default_value' => \Drupal::config('miniorange_saml.settings')->get('miniorange_saml_role_' . $rolelabel),
            '#attributes' => array('style' => 'width:700px;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Semi-colon(;) separated Group/Role value for ' . $roles),
            '#disabled' => TRUE,
        );
      }

      $form['miniorange_saml_gateway_config4_submit'] = array(
          '#type' => 'submit',
          '#value' => t('Save Configuration'),
          '#disabled' => TRUE,
          '#prefix' => '<br>',
          '#suffix' => '<br><br></div>',
      );

     Utilities::spConfigGuide($form, $form_state);

     Utilities::AddSupportButton($form, $form_state);

     return $form;

 }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        $username_attribute = $form['miniorange_saml_username_attribute']['#value'];
        $email_attribute = $form['miniorange_saml_email_attribute']['#value'];
        $enable_rolemapping = $form['miniorange_saml_enable_rolemapping']['#value'];
        $default_mapping = $form['miniorange_saml_default_mapping']['#value'];

        $i = 0;
        $mrole = user_role_names(TRUE );
        foreach( $mrole as $key => $value ) {
            $def_role[$i] = $value;
            $i++;
        }

        $enable_rolemapping_value = $enable_rolemapping == 1 ? TRUE : FALSE;

        if( $enable_rolemapping_value ) {
            \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_default_role', $def_role[$default_mapping]);
            \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_default_role_index', $default_mapping);
        }else {
            \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_default_role', $mrole['authenticated'])->save();
        }

        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_username_attribute', $username_attribute)->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_email_attribute', $email_attribute)->save();
        \Drupal::configFactory()->getEditable('miniorange_saml.settings')->set('miniorange_saml_enable_rolemapping', $enable_rolemapping_value)->save();
        \Drupal::messenger()->addMessage(t('Signin Settings successfully saved'), 'status');
    }
  }